==> vtk-7.1.1-4-armv7h.pkg.tar.xz: vtk/vtkBoxRepresentation.java <==
// java wrapper for vtkBoxRepresentation object
//

package vtk;
import vtk.*;

public class vtkBoxRepresentation extends vtkWidgetRepresentation
{

  private native String GetClassName_0();
  public String GetClassName()
    { return GetClassName_0(); }

  private native int IsA_1(String id0);
  public int IsA(String id0)
    { return IsA_1(id0); }

  private native void GetPlanes_2(vtkPlanes id0);
  public void GetPlanes(vtkPlanes id0)
    { GetPlanes_2(id0); }

  private native void SetInsideOut_3(int id0);
  public void SetInsideOut(int id0)
    { SetInsideOut_3(id0); }

  private native int GetInsideOut_4();
  public int GetInsideOut()
    { return GetInsideOut_4(); }

  private native void InsideOutOn_5();
  public void InsideOutOn()
    { InsideOutOn_5(); }

  private native void InsideOutOff_6();
  public void InsideOutOff()
    { InsideOutOff_6(); }

  private native void GetTransform_7(vtkTransform id0);
  public void GetTransform(vtkTransform id0)
    { GetTransform_7(id0); }

  private native void SetTransform_8(vtkTransform id0);
  public void SetTransform(vtkTransform id0)
    { SetTransform_8(id0); }

  private native void GetPolyData_9(vtkPolyData id0);
  public void GetPolyData(vtkPolyData id0)
    { GetPolyData_9(id0); }

  private native long GetHandleProperty_10();
  public vtkProperty GetHandleProperty() {
    long temp = GetHandleProperty_10();

    if (temp == 0) return null;
    return (vtkProperty)vtkObjectBase.JAVA_OBJECT_MANAGER.getJavaObject(temp);
}

  private native long GetSelectedHandleProperty_11();
  public vtkProperty GetSelectedHandleProperty() {
    long temp = GetSelectedHandleProperty_11();

    if (temp == 0) return null;
    return (vtkProperty)vtkObjectBase.JAVA_OBJECT_MANAGER.getJavaObject(temp);
}

  private native long GetFaceProperty_12();
  public vtkProperty GetFaceProperty() {
    long temp = GetFaceProperty_12();

    if (temp == 0) return null;
    return (vtkProperty)vtkObjectBase.JAVA_OBJECT_MANAGER.getJavaObject(temp);
}

  private native long GetSelectedFaceProperty_13();
  public vtkProperty GetSelectedFaceProperty() {
    long temp = GetSelectedFaceProperty_13();

    if (temp == 0) return null;
    return (vtkProperty)vtkObjectBase.JAVA_OBJECT_MANAGER.getJavaObject(temp);
}

  private native long GetOutlineProperty_14();
  public vtkProperty GetOutlineProperty() {
    long temp = GetOutlineProperty_14();

    if (temp == 0) return null;
    return (vtkProperty)vtkObjectBase.JAVA_OBJECT_MANAGER.getJavaObject(temp);
}

  private native long GetSelectedOutlineProperty_15();
  public vtkProperty GetSelectedOutlineProperty() {
    long temp = GetSelectedOutlineProperty_15();

    if (temp == 0) return null;
    return (vtkProperty)vtkObjectBase.JAVA_OBJECT_MANAGER.getJavaObject(temp);
}

  private native void SetOutlineFaceWires_16(int id0);
  public void SetOutlineFaceWires(int id0)
    { SetOutlineFaceWires_16(id0); }

  private native int GetOutlineFaceWires_17();
  public int GetOutlineFaceWires()
    { return GetOutlineFaceWires_17(); }

  private native void OutlineFaceWiresOn_18();
  public void OutlineFaceWiresOn()
    { OutlineFaceWiresOn_18(); }

  private native void OutlineFaceWiresOff_19();
  public void OutlineFaceWiresOff()
    { OutlineFaceWiresOff_19(); }

  private native void SetOutlineCursorWires_20(int id0);
  public void SetOutlineCursorWires(int id0)
    { SetOutlineCursorWires_20(id0); }

  private native int GetOutlineCursorWires_21();
  public int GetOutlineCursorWires()
    { return GetOutlineCursorWires_21(); }

  private native void OutlineCursorWiresOn_22();
  public void OutlineCursorWiresOn()
    { OutlineCursorWiresOn_22(); }

  private native void OutlineCursorWiresOff_23();
  public void OutlineCursorWiresOff()
    { OutlineCursorWiresOff_23(); }

  private native void HandlesOn_24();
  public void HandlesOn()
    { HandlesOn_24(); }

  private native void HandlesOff_25();
  public void HandlesOff()
    { HandlesOff_25(); }

  private native void PlaceWidget_26(double id0[]);
  public void PlaceWidget(double id0[])
    { PlaceWidget_26(id0); }

  private native void BuildRepresentation_27();
  public void BuildRepresentation()
    { BuildRepresentation_27(); }

  private native int ComputeInteractionState_28(int id0,int id1,int id2);
  public int ComputeInteractionState(int id0,int id1,int id2)
    { return ComputeInteractionState_28(id0,id1,id2); }

  private native void StartWidgetInteraction_29(double id0[]);
  public void StartWidgetInteraction(double id0[])
    { StartWidgetInteraction_29(id0); }

  private native void WidgetInteraction_30(double id0[]);
  public void WidgetInteraction(double id0[])
    { WidgetInteraction_30(id0); }

  private native double[] GetBounds_31();
  public double[] GetBounds()
    { return GetBounds_31(); }

  private native void ReleaseGraphicsResources_32(vtkWindow id0);
  public void ReleaseGraphicsResources(vtkWindow id0)
    { ReleaseGraphicsResources_32(id0); }

  private native int RenderOpaqueGeometry_33(vtkViewport id0);
  public int RenderOpaqueGeometry(vtkViewport id0)
    { return RenderOpaqueGeometry_33(id0); }

  private native int RenderTranslucentPolygonalGeometry_34(vtkViewport id0);
  public int RenderTranslucentPolygonalGeometry(vtkViewport id0)
    { return RenderTranslucentPolygonalGeometry_34(id0); }

  private native int HasTranslucentPolygonalGeometry_35();
  public int HasTranslucentPolygonalGeometry()
    { return HasTranslucentPolygonalGeometry_35(); }

  private native void SetInteractionState_36(int id0);
  public void SetInteractionState(int id0)
    { SetInteractionState_36(id0); }

  public vtkBoxRepresentation() { super(); }

  public vtkBoxRepresentation(long id) { super(id); }
  public native long   VTKInit();

}

==> vtk-8.0.1-3-armv7h.pkg.tar.xz: vtk/vtkBoxRepresentation.java <==
// java wrapper for vtkBoxRepresentation object
//

package vtk;
import vtk.*;

public class vtkBoxRepresentation extends vtkWidgetRepresentation
{

  private native int IsTypeOf_0(String id0);
  public int IsTypeOf(String id0)
    { return IsTypeOf_0(id0); }

  private native int IsA_1(String id0);
  public int IsA(String id0)
    { return IsA_1(id0); }

  private native void GetPlanes_2(vtkPlanes id0);
  public void GetPlanes(vtkPlanes id0)
    { GetPlanes_2(id0); }

  private native void SetInsideOut_3(int id0);
  public void SetInsideOut(int id0)
    { SetInsideOut_3(id0); }

  private native int GetInsideOut_4();
  public int GetInsideOut()
    { return GetInsideOut_4(); }

  private native void InsideOutOn_5();
  public void InsideOutOn()
    { InsideOutOn_5(); }

  private native void InsideOutOff_6();
  public void InsideOutOff()
    { InsideOutOff_6(); }

  private native void GetTransform_7(vtkTransform id0);
  public void GetTransform(vtkTransform id0)
    { GetTransform_7(id0); }

  private native void SetTransform_8(vtkTransform id0);
  public void SetTransform(vtkTransform id0)
    { SetTransform_8(id0); }

  private native void GetPolyData_9(vtkPolyData id0);
  public void GetPolyData(vtkPolyData id0)
    { GetPolyData_9(id0); }

  private native long GetHandleProperty_10();
  public vtkProperty GetHandleProperty() {
    long temp = GetHandleProperty_10();

    if (temp == 0) return null;
    return (vtkProperty)vtkObjectBase.JAVA_OBJECT_MANAGER.getJavaObject(temp);
}

  private native long GetSelectedHandleProperty_11();
  public vtkProperty GetSelectedHandleProperty() {
    long temp = GetSelectedHandleProperty_11();

    if (temp == 0) return null;
    return (vtkProperty)vtkObjectBase.JAVA_OBJECT_MANAGER.getJavaObject(temp);
}

  private native long GetFaceProperty_12();
  public vtkProperty GetFaceProperty() {
    long temp = GetFaceProperty_12();

    if (temp == 0) return null;
    return (vtkProperty)vtkObjectBase.JAVA_OBJECT_MANAGER.getJavaObject(temp);
}

  private native long GetSelectedFaceProperty_13();
  public vtkProperty GetSelectedFaceProperty() {
    long temp = GetSelectedFaceProperty_13();

    if (temp == 0) return null;
    return (vtkProperty)vtkObjectBase.JAVA_OBJECT_MANAGER.getJavaObject(temp);
}

  private native long GetOutlineProperty_14();
  public vtkProperty GetOutlineProperty() {
    long temp = GetOutlineProperty_14();

    if (temp == 0) return null;
    return (vtkProperty)vtkObjectBase.JAVA_OBJECT_MANAGER.getJavaObject(temp);
}

  private native long GetSelectedOutlineProperty_15();
  public vtkProperty GetSelectedOutlineProperty() {
    long temp = GetSelectedOutlineProperty_15();

    if (temp == 0) return null;
    return (vtkProperty)vtkObjectBase.JAVA_OBJECT_MANAGER.getJavaObject(temp);
}

  private native void SetOutlineFaceWires_16(int id0);
  public void SetOutlineFaceWires(int id0)
    { SetOutlineFaceWires_16(id0); }

  private native int GetOutlineFaceWires_17();
  public int GetOutlineFaceWires()
    { return GetOutlineFaceWires_17(); }

  private native void OutlineFaceWiresOn_18();
  public void OutlineFaceWiresOn()
    { OutlineFaceWiresOn_18(); }

  private native void OutlineFaceWiresOff_19();
  public void OutlineFaceWiresOff()
    { OutlineFaceWiresOff_19(); }

  private native void SetOutlineCursorWires_20(int id0);
  public void SetOutlineCursorWires(int id0)
    { SetOutlineCursorWires_20(id0); }

  private native int GetOutlineCursorWires_21();
  public int GetOutlineCursorWires()
    { return GetOutlineCursorWires_21(); }

  private native void OutlineCursorWiresOn_22();
  public void OutlineCursorWiresOn()
    { OutlineCursorWiresOn_22(); }

  private native void OutlineCursorWiresOff_23();
  public void OutlineCursorWiresOff()
    { OutlineCursorWiresOff_23(); }

  private native void HandlesOn_24();
  public void HandlesOn()
    { HandlesOn_24(); }

  private native void HandlesOff_25();
  public void HandlesOff()
    { HandlesOff_25(); }

  private native void PlaceWidget_26(double id0[]);
  public void PlaceWidget(double id0[])
    { PlaceWidget_26(id0); }

  private native void BuildRepresentation_27();
  public void BuildRepresentation()
    { BuildRepresentation_27(); }

  private native int ComputeInteractionState_28(int id0,int id1,int id2);
  public int ComputeInteractionState(int id0,int id1,int id2)
    { return ComputeInteractionState_28(id0,id1,id2); }

  private native void StartWidgetInteraction_29(double id0[]);
  public void StartWidgetInteraction(double id0[])
    { StartWidgetInteraction_29(id0); }

  private native void WidgetInteraction_30(double id0[]);
  public void WidgetInteraction(double id0[])
    { WidgetInteraction_30(id0); }

  private native double[] GetBounds_31();
  public double[] GetBounds()
    { return GetBounds_31(); }

  private native void ReleaseGraphicsResources_32(vtkWindow id0);
  public void ReleaseGraphicsResources(vtkWindow id0)
    { ReleaseGraphicsResources_32(id0); }

  private native int RenderOpaqueGeometry_33(vtkViewport id0);
  public int RenderOpaqueGeometry(vtkViewport id0)
    { return RenderOpaqueGeometry_33(id0); }

  private native int RenderTranslucentPolygonalGeometry_34(vtkViewport id0);
  public int RenderTranslucentPolygonalGeometry(vtkViewport id0)
    { return RenderTranslucentPolygonalGeometry_34(id0); }

  private native int HasTranslucentPolygonalGeometry_35();
  public int HasTranslucentPolygonalGeometry()
    { return HasTranslucentPolygonalGeometry_35(); }

  private native void SetInteractionState_36(int id0);
  public void SetInteractionState(int id0)
    { SetInteractionState_36(id0); }

  public vtkBoxRepresentation() { super(); }

  public vtkBoxRepresentation(long id) { super(id); }
  public native long   VTKInit();

}
